Installation — django-authopenid v1.0 documentation

### Navigation

- index
- next |
- previous |
- django-authopenid v1.0 documentation »

# Installation

The most recent release is always available in the cheeseshop and can be installed using easy_install:

    easy_install django-authopenid

Alternatly, you can also install the development version from our Mercurial repository:

    hg clone https://dev.e-engura.org/hg/django-authopenid
    cd django-authopenid
    sudo python setup.py install

Last command will install django-authopenid as a package via setuptools. This will make it available in your python path. Alternately you can copy or symlink the django-authopenid subdirectory into your django project directory or anywhere in your PYTHONPATH.

You could also get source from Bitbucket

    hg clone http://hg.e-engura.org/django-authopenid/

# Requirements

To use django-authopenid you will need Python 2.5 or later, Django 1.0 or later and django-registration .

### Navigation

- index
- next |
- previous |
- django-authopenid v1.0 documentation »